==> digikam-3.2.0.tar.bz2: digikam-3.2.0/extra/kipi-plugins/jalbumexport/kipiplugin_jalbumexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=jAlbumExport
Name=jAlbumExport
Name[ca]=Exportador a jAlbum
Name[cs]=jAlbumExport
Name[da]=jAlbumExport
Name[de]=jAlbum-Export
Name[el]=jAlbumExport
Name[is]=jAlbum-útflutningur
Name[it]=jAlbumExport
Name[nl]=jAlbum-export
Name[pt]=jAlbumExport
Name[pt_BR]=jAlbumExport
Name[sl]=jAlbumExport
Name[sv]=Export till jAlbum
Name[uk]=Експорт до jAlbum
Name[x-test]=xxjAlbumExportxx
Comment=A tool to pass selected photos to jAlbum
Comment[ca]=Una eina per passar les fotografies seleccionades a jAlbum
Comment[da]=Et værktøj til at sende udvalgte fotos til jAlbum
Comment[el]=Εργαλείο για να περαστούν επιλεγμένες φωτογραφίες στο jAlbum
Comment[is]=Verkfæri til að senda myndir á jAlbum
Comment[it]=Uno strumento per esportare le foto selezionate a jAlbum
Comment[nl]=Een hulpmiddel om geselecteerde foto's aan jAlbum te overhandigen
Comment[pt]=Uma ferramenta para passar as fotografias seleccionadas para o jAlbum
Comment[pt_BR]=Ferramenta de envio das fotos selecionadas para o jAlbum
Comment[sl]=Orodje za premestitev izbranih fotografij v jAlbum
Comment[sv]=Ett verktyg för att skicka markerade foton till jAlbum
Comment[uk]=Інструмент для передавання позначених фотографій до jAlbum
Comment[x-test]=xxA tool to pass selected photos to jAlbumxx
Type=Service
Icon=jalbum
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jalbumexport
author=Andrew Goodbody, ajg zero two at elfringham dot co dot uk
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=

==> digikam-3.3.0.tar.bz2: digikam-3.3.0/extra/kipi-plugins/jalbumexport/kipiplugin_jalbumexport.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
UntranslatedGenericName=jAlbumExport
Name=jAlbumExport
Name[ca]=Exportador a jAlbum
Name[cs]=jAlbumExport
Name[da]=jAlbumExport
Name[de]=jAlbum-Export
Name[el]=jAlbumExport
Name[fr]=Exportation « jAlbum »
Name[gl]=jAlbumExport
Name[hu]=jAlbum exportálás
Name[is]=jAlbum-útflutningur
Name[it]=jAlbumExport
Name[nl]=jAlbum-export
Name[pl]=jAlbumExport
Name[pt]=jAlbumExport
Name[pt_BR]=jAlbumExport
Name[sl]=jAlbumExport
Name[sv]=Export till jAlbum
Name[uk]=Експорт до jAlbum
Name[x-test]=xxjAlbumExportxx
Name[zh_TW]=jAlbum 匯出
Comment=A tool to pass selected photos to jAlbum
Comment[ca]=Una eina per passar les fotografies seleccionades a jAlbum
Comment[da]=Et værktøj til at sende udvalgte fotos til jAlbum
Comment[el]=Εργαλείο για να περαστούν επιλεγμένες φωτογραφίες στο jAlbum
Comment[fr]=Un outil pour envoyer les images sélectionnées vers jAlbum
Comment[gl]=Ferramenta para enviar as imaxes seleccionadas a jAlbum.
Comment[hu]=Egy eszköz a kijelölt fényképek átadásához a jAlbumba
Comment[is]=Verkfæri til að senda myndir á jAlbum
Comment[it]=Uno strumento per esportare le foto selezionate a jAlbum
Comment[nl]=Een hulpmiddel om geselecteerde foto's aan jAlbum te overhandigen
Comment[pl]=Narzędzie do przesyłania wybranych zdjęć do jAlbum
Comment[pt]=Uma ferramenta para passar as fotografias seleccionadas para o jAlbum
Comment[pt_BR]=Ferramenta de envio das fotos selecionadas para o jAlbum
Comment[sl]=Orodje za premestitev izbranih fotografij v jAlbum
Comment[sv]=Ett verktyg för att skicka markerade foton till jAlbum
Comment[uk]=Інструмент для передавання позначених фотографій до jAlbum
Comment[x-test]=xxA tool to pass selected photos to jAlbumxx
Comment[zh_TW]=匯出選取的相片到 jAlbum 的工具
Type=Service
Icon=kipi-jalbum
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_jalbumexport
author=Andrew Goodbody, ajg zero two at elfringham dot co dot uk
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-ReqFeatures=
